aboutsummaryrefslogtreecommitdiff
path: root/gdb/arch-utils.h
diff options
context:
space:
mode:
Diffstat (limited to 'gdb/arch-utils.h')
-rw-r--r--gdb/arch-utils.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/gdb/arch-utils.h b/gdb/arch-utils.h
index 9934bbf..071b530 100644
--- a/gdb/arch-utils.h
+++ b/gdb/arch-utils.h
@@ -111,10 +111,12 @@ extern int default_prepare_to_proceed (int select_it);
extern int generic_prepare_to_proceed (int select_it);
/* Version of init_frame_pc() that does nothing. */
void init_frame_pc_noop (int fromleaf, struct frame_info *prev);
+void init_frame_pc_default (int fromleaf, struct frame_info *prev);
+
/* Version of cannot_fetch_register() / cannot_store_register() that
always fails. */
@@ -111,10 +111,12 @@ extern int default_prepare_to_proceed (int select_it);
extern int generic_prepare_to_proceed (int select_it);
-/* Version of init_frame_pc() that does nothing. */
+/* Versions of init_frame_pc(). Do nothing; do the default. */
void init_frame_pc_noop (int fromleaf, struct frame_info *prev);